@@ -39,3 +39,35 @@ _DES_PARITYTABLE = bytearray((
 
 def des_set_odd_parity(key: bytearray):
     key[:] = (_DES_PARITYTABLE[b] for b in key)
+
+
+def rotl64(x: int, c: int):
+    return ((x << c) | (x >> (0x40 - c))) & 0xFFFFFFFF
+
+
+def rotl32(x: int, c: int):
+    return ((x << c) | (x >> (0x20 - c))) & 0xFFFFFFFF
+
+
+def rotl16(x: int, c: int):
+    return ((x << c) | (x >> (0x10 - c))) & 0xFFFFFFFF
+
+
+def rotl08(x: int, c: int):
+    return ((x << c) | (x >> (0x08 - c))) & 0xFFFFFFFF
+
+
+def rotr64(x: int, c: int):
+    return (x << (0x40 - c) & 0xFFFFFFFF) | (x >> c)
+
+
+def rotr32(x: int, c: int):
+    return (x << (0x20 - c) & 0xFFFFFFFF) | (x >> c)
+
+
+def rotr16(x: int, c: int):
+    return (x << (0x10 - c) & 0xFFFFFFFF) | (x >> c)
+
+
+def rotr08(x: int, c: int):
+    return (x << (0x08 - c) & 0xFFFFFFFF) | (x >> c)
