@@ -13,8 +13,12 @@ class url(Unit):
     with a percent symbol.
     """
 
-    def __init__(self, plus: arg.switch('-p', help='also replace plus signs by spaces') = False):
-        super().__init__(plus=plus)
+    def __init__(
+        self,
+        plus: arg.switch('-p', help='also replace plus signs by spaces') = False,
+        hex : arg.switch('-x', help='hex encode every character in reverse mode') = False
+    ):
+        super().__init__(plus=plus, hex=hex)
 
     def process(self, data):
         data = re.sub(
@@ -29,9 +33,13 @@ class url(Unit):
     def reverse(self, data):
         if self.args.plus:
             data = data.replace(B' ', B'+')
-        data = re.sub(
-            B'[^a-zA-Z0-9_.-~\\/]',
-            lambda m: B'%%%02X' % ord(m[0]),
-            data
-        )
-        return data
+        if not self.args.hex:
+            return re.sub(B'[^a-zA-Z0-9_.-~\\/]', lambda m: B'%%%02X' % ord(m[0]), data)
+        result = bytearray(len(data) * 3)
+        offset = 0
+        for byte in data:
+            result[offset] = B'%'[0]
+            offset += 1
+            result[offset:offset + 2] = B'%02X' % byte
+            offset += 2
+        return result
