@@ -1,13 +1,14 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from ..strings.rep import rep
+from .. import Unit, arg
 
 
-class push(rep):
+class push(Unit):
     """
-    The unit operates almost exactly as `refinery.rep`, except that the last copy of the
-    data is moved out of scope. This chunk is considered the "original" data, while all
-    other chunks are to be used as intermediate results. For example:
+    The unit inserts an additional chunk before each input chunk and moves the original
+    data out of scope. This chunk is considered the "original" data, while the one inserted
+    in front of it is used as an intermediate result. By default, this intermediate data is
+    a copy of the input data. For example:
 
         emit key=value | push [[| rex =(.*)$ $1 | pop v ]| repl var:v censored ]
 
@@ -15,9 +16,11 @@ class push(rep):
     data into just the value, which is then stored in the variable `v`. The application
     of `refinery.repl` replaces this value with the hard-coded string `censored`.
     """
+    def __init__(self, data: arg(help='The data to be pushed, by default a copy of the input.') = B''):
+        super().__init__(data=data)
+
     def process(self, data):
-        for _ in range(self.args.count - 1):
-            yield data
+        yield self.args.data or data
         if self.args.nesting > 0:
             data.set_next_scope(False)
         else:
