@@ -8,7 +8,7 @@ class ccp(Unit):
     Prepend data to the input.
     """
 
-    def __init__(self, *data: arg.help('Binary strings to be prepended to the input.')):
+    def __init__(self, *data: arg(help='Binary strings to be prepended to the input.')):
         super().__init__(data=data)
 
     def process(self, data):
