@@ -1,5 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+from itertools import repeat
+
 from .. import arg, Unit
 
 
@@ -9,10 +11,9 @@ class rep(Unit):
     """
 
     def __init__(self, count: arg(help='Defines the number of outputs for each input. The default is the minimum of 2.') = 2):
-        if count < 2:
-            raise ValueError('The count must be at least two.')
         super().__init__(count=count)
 
     def process(self, data: bytes):
-        from itertools import repeat
+        if self.args.count < 2:
+            raise ValueError('The count must be at least two.')
         yield from repeat(data, self.args.count)
